@@ -47,7 +47,8 @@ using namespace boost::lambda;
 using namespace boost;
 using namespace std;
 
-DiscoverableMetadataProvider::DiscoverableMetadataProvider(const DOMElement* e) : MetadataProvider(e), m_legacyOrgNames(false)
+DiscoverableMetadataProvider::DiscoverableMetadataProvider(const DOMElement* e, bool deprecationSupport)
+    : MetadataProvider(e, deprecationSupport), m_legacyOrgNames(false)
 {
     static const XMLCh legacyOrgNames[] =   UNICODE_LITERAL_14(l,e,g,a,c,y,O,r,g,N,a,m,e,s);
     static const XMLCh matcher[] =          UNICODE_LITERAL_7(m,a,t,c,h,e,r);
@@ -65,7 +66,7 @@ DiscoverableMetadataProvider::DiscoverableMetadataProvider(const DOMElement* e)
             string m(XMLHelper::getAttrString(e, nullptr, matcher));
             if (!m.empty()) {
                 try {
-                    boost::shared_ptr<EntityMatcher> temp(SAMLConfig::getConfig().EntityMatcherManager.newPlugin(m, e));
+                    boost::shared_ptr<EntityMatcher> temp(SAMLConfig::getConfig().EntityMatcherManager.newPlugin(m, e, deprecationSupport));
                     m_discoFilters.push_back(make_pair(t == "Whitelist", temp));
                 }
                 catch (std::exception& ex) {
