@@ -36,6 +36,7 @@
 #include <xmltooling/util/NDC.h>
 #include <xmltooling/util/XMLHelper.h>
 
+#include <errno.h>
 using namespace opensaml::saml2md;
 using namespace opensaml;
 using namespace xmltooling::logging;
@@ -47,7 +48,7 @@ using namespace std;
 namespace opensaml {
     namespace saml2md {
         SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory XMLMetadataProviderFactory;
-        SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory DynamicMetadataProviderFactory;
+        SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory LocalDynamicMetadataProviderFactory;
         SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory ChainingMetadataProviderFactory;
         SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory FolderMetadataProviderFactory;
         SAML_DLLLOCAL PluginManager<MetadataProvider,string,const DOMElement*>::Factory NullMetadataProviderFactory;
@@ -64,7 +65,7 @@ void SAML_API opensaml::saml2md::registerMetadataProviders()
 {
     SAMLConfig& conf=SAMLConfig::getConfig();
     conf.MetadataProviderManager.registerFactory(XML_METADATA_PROVIDER, XMLMetadataProviderFactory);
-    conf.MetadataProviderManager.registerFactory(DYNAMIC_METADATA_PROVIDER, DynamicMetadataProviderFactory);
+    conf.MetadataProviderManager.registerFactory(LOCAL_DYNAMIC_METADATA_PROVIDER, LocalDynamicMetadataProviderFactory);
     conf.MetadataProviderManager.registerFactory(CHAINING_METADATA_PROVIDER, ChainingMetadataProviderFactory);
     conf.MetadataProviderManager.registerFactory(FOLDER_METADATA_PROVIDER, FolderMetadataProviderFactory);
     conf.MetadataProviderManager.registerFactory(NULL_METADATA_PROVIDER, NullMetadataProviderFactory);
@@ -91,56 +92,60 @@ static const XMLCh Exclude[] =          UNICODE_LITERAL_7(E,x,c,l,u,d,e);
 static const XMLCh Include[] =          UNICODE_LITERAL_7(I,n,c,l,u,d,e);
 static const XMLCh _type[] =            UNICODE_LITERAL_4(t,y,p,e);
 
-MetadataProvider::MetadataProvider(const DOMElement* e) : m_filterContext(nullptr)
+MetadataProvider::MetadataProvider() { throw MetadataException("Illegal constructor call"); }
+
+MetadataProvider::MetadataProvider(const DOMElement* e, bool deprecationSupport) : m_filterContext(nullptr)
 {
 #ifdef _DEBUG
     NDC ndc("MetadataProvider");
 #endif
-    Category& log = Category::getInstance(SAML_LOGCAT ".Metadata");
-    SAMLConfig& conf = SAMLConfig::getConfig();
+    Category& log = Category::getInstance(SAML_LOGCAT ".MetadataProvider");
+    const SAMLConfig& conf = SAMLConfig::getConfig();
 
     // Locate any default recognized filters and plugins.
-    try {
-        DOMElement* child = XMLHelper::getFirstChildElement(e);
-        while (child) {
-            if (XMLString::equals(child->getLocalName(), _MetadataFilter)) {
-                string t = XMLHelper::getAttrString(child, nullptr, _type);
-                if (!t.empty()) {
-                    log.info("building MetadataFilter of type %s", t.c_str());
-                    auto_ptr<MetadataFilter> np(conf.MetadataFilterManager.newPlugin(t.c_str(), child));
-                    m_filters.push_back(np.get());
-                    np.release();
-                }
-                else {
-                    log.error("MetadataFilter element missing type attribute");
-                }
+    DOMElement* child = XMLHelper::getFirstChildElement(e);
+    while (child) {
+        if (XMLString::equals(child->getLocalName(), _MetadataFilter)) {
+            string t = XMLHelper::getAttrString(child, nullptr, _type);
+            if (!t.empty()) {
+                log.info("building MetadataFilter of type %s", t.c_str());
+                auto_ptr<MetadataFilter> np(conf.MetadataFilterManager.newPlugin(t.c_str(), child, deprecationSupport));
+                m_filters.push_back(np.get());
+                np.release();
             }
-            else if (XMLString::equals(child->getLocalName(), SigFilter)) {
-                log.info("building MetadataFilter of type %s", SIGNATURE_METADATA_FILTER);
-                m_filters.push_back(conf.MetadataFilterManager.newPlugin(SIGNATURE_METADATA_FILTER, child));
+            else {
+                log.error("MetadataFilter element missing type attribute");
             }
-            else if (XMLString::equals(child->getLocalName(), Whitelist)) {
-                log.info("building MetadataFilter of type %s", WHITELIST_METADATA_FILTER);
-                m_filters.push_back(conf.MetadataFilterManager.newPlugin(WHITELIST_METADATA_FILTER, child));
-            }
-            else if (XMLString::equals(child->getLocalName(), Blacklist)) {
-                log.info("building MetadataFilter of type %s", BLACKLIST_METADATA_FILTER);
-                m_filters.push_back(conf.MetadataFilterManager.newPlugin(BLACKLIST_METADATA_FILTER, child));
-            }
-            else if (XMLString::equals(child->getLocalName(), Include)) {
-                log.info("building MetadataFilter of type %s", WHITELIST_METADATA_FILTER);
-                m_filters.push_back(conf.MetadataFilterManager.newPlugin(WHITELIST_METADATA_FILTER, e));
-            }
-            else if (XMLString::equals(child->getLocalName(), Exclude)) {
-                log.info("building MetadataFilter of type %s", BLACKLIST_METADATA_FILTER);
-                m_filters.push_back(conf.MetadataFilterManager.newPlugin(BLACKLIST_METADATA_FILTER, e));
-            }
-            child = XMLHelper::getNextSiblingElement(child);
         }
-    }
-    catch (XMLToolingException& ex) {
-        log.error("caught exception while installing filters: %s", ex.what());
-        throw;
+        else if (deprecationSupport && XMLString::equals(child->getLocalName(), SigFilter)) {
+            log.warn("DEPRECATED: <SignatureMetadataFilter> replaced by type=\"%s\"", SIGNATURE_METADATA_FILTER);
+            log.info("building MetadataFilter of type %s", SIGNATURE_METADATA_FILTER);
+            m_filters.push_back(conf.MetadataFilterManager.newPlugin(SIGNATURE_METADATA_FILTER, child, deprecationSupport));
+        }
+        else if (deprecationSupport && XMLString::equals(child->getLocalName(), Whitelist)) {
+            log.warn("DEPRECATED: <WhitelistMetadataFilter> replaced by type=\"%s\"", WHITELIST_METADATA_FILTER);
+            log.info("building MetadataFilter of type %s", WHITELIST_METADATA_FILTER);
+            m_filters.push_back(conf.MetadataFilterManager.newPlugin(WHITELIST_METADATA_FILTER, child, deprecationSupport));
+        }
+        else if (deprecationSupport && XMLString::equals(child->getLocalName(), Blacklist)) {
+            log.warn("DEPRECATED: <BlacklistMetadataFilter> replaced by type=\"%s\"", BLACKLIST_METADATA_FILTER);
+            log.info("building MetadataFilter of type %s", BLACKLIST_METADATA_FILTER);
+            m_filters.push_back(conf.MetadataFilterManager.newPlugin(BLACKLIST_METADATA_FILTER, child, deprecationSupport));
+        }
+        else if (deprecationSupport && XMLString::equals(child->getLocalName(), Include)) {
+            log.warn("DEPRECATED: <Include> replaced by type=\"%s\"", WHITELIST_METADATA_FILTER);
+            log.info("building MetadataFilter of type %s", WHITELIST_METADATA_FILTER);
+            m_filters.push_back(conf.MetadataFilterManager.newPlugin(WHITELIST_METADATA_FILTER, e, deprecationSupport));
+        }
+        else if (deprecationSupport && XMLString::equals(child->getLocalName(), Exclude)) {
+            log.warn("DEPRECATED: replaced by type=\"%s\"", BLACKLIST_METADATA_FILTER);
+            log.info("building MetadataFilter of type %s", BLACKLIST_METADATA_FILTER);
+            m_filters.push_back(conf.MetadataFilterManager.newPlugin(BLACKLIST_METADATA_FILTER, e, deprecationSupport));
+        }
+        else if (!deprecationSupport && XMLString::endsWith(child->getLocalName(), _MetadataFilter)) {
+            throw UnknownExtensionException("Unsupported metadata filter syntax detected.");
+        }
+        child = XMLHelper::getNextSiblingElement(child);
     }
 }
 
@@ -172,31 +177,15 @@ void MetadataProvider::setContext(const MetadataFilterContext* ctx)
     m_filterContext = ctx;
 }
 
-void MetadataProvider::doFiltersInternal(const MetadataFilterContext* ctx, XMLObject& xmlObject) const
-{
-    Category& log = Category::getInstance(SAML_LOGCAT ".Metadata");
-    for (ptr_vector<MetadataFilter>::const_iterator i = m_filters.begin(); i != m_filters.end(); i++) {
-        log.info("applying metadata filter (%s)", i->getId());
-        i->doFilter(ctx, xmlObject);
-    }
-}
-
 void MetadataProvider::doFilters(const MetadataFilterContext* ctx, XMLObject& xmlObject) const
 {
-    if (m_filterContext) {
-        Category& log = Category::getInstance(SAML_LOGCAT ".Metadata");
-        log.crit("Internal error: calling MetadataProvider::doFilters with a static and dynamic context");
-        throw;
+    Category& log = Category::getInstance(SAML_LOGCAT ".MetadataProvider");
+    for (ptr_vector<MetadataFilter>::const_iterator i = m_filters.begin(); i != m_filters.end(); i++) {
+        log.info("applying metadata filter (%s)", i->getId());
+        i->doFilter(ctx ? ctx : m_filterContext, xmlObject);
     }
-    doFiltersInternal(ctx, xmlObject);
 }
 
-void MetadataProvider::doFilters(XMLObject& xmlObject) const
-{
-    doFiltersInternal(m_filterContext, xmlObject);
-}
-
-
 void MetadataProvider::outputStatus(ostream& os) const
 {
 }
@@ -250,17 +239,6 @@ MetadataFilter::~MetadataFilter()
 {
 }
 
-void MetadataFilter::doFilter(const MetadataFilterContext* ctx, xmltooling::XMLObject& xmlObject) const
-{
-    // Default call into deprecated method.
-    doFilter(xmlObject);
-}
-
-void MetadataFilter::doFilter(xmltooling::XMLObject& xmlObject) const
-{
-    // Empty default for deprecated method.
-}
-
 MetadataFilterContext::MetadataFilterContext()
 {
 }
@@ -286,4 +264,4 @@ bool BatchLoadMetadataFilterContext::isBackingFile() const
 void BatchLoadMetadataFilterContext::setBackingFile(bool flag)
 {
     m_isBackingFile = flag;
-}
\ No newline at end of file
+}
