@@ -23,6 +23,7 @@
 #include <saml/saml2/binding/SAML2ArtifactType0004.h>
 #include <saml/saml2/metadata/Metadata.h>
 #include <saml/saml2/metadata/MetadataProvider.h>
+#include <saml/saml2/metadata/MetadataFilter.h>
 #include <xmltooling/security/SecurityHelper.h>
 
 using namespace opensaml::saml2md;
@@ -52,7 +53,48 @@ public:
         SAMLObjectBaseTestCase::tearDown();
     }
 
+    void testBadSig()
+    {
+        string config = data_path + "saml2/metadata/XMLMetadataProviderBadSig.xml";
+        ifstream in(config.c_str());
+        DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
+        XercesJanitor<DOMDocument> janitor(doc);
+
+        scoped_ptr<MetadataProvider> metadataProvider(
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER, doc->getDocumentElement(), false)
+            );
+        try {
+            metadataProvider->init();
+        } catch (const MetadataFilterException& ex) {
+            TS_TRACE(ex.what());
+            return;
+        }
+        catch (const XMLToolingException& ex) {
+            TS_TRACE(ex.what());
+            throw;
+        }
+    }
+
+    void testBadChain()
+    {
+        string config = data_path + "saml2/metadata/BadChain.xml";
+        ifstream in(config.c_str());
+        DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
+        XercesJanitor<DOMDocument> janitor(doc);
+
+        scoped_ptr<MetadataProvider> metadataProvider(
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(CHAINING_METADATA_PROVIDER, doc->getDocumentElement(), false)
+            );
+        try {
+            metadataProvider->init();
+        } catch (const XMLToolingException& ex) {
+            TS_TRACE(ex.what());
+            throw;
+        }
+    }
+
     void testXMLProvider() {
+        skipNetworked();
         string config = data_path + "saml2/metadata/XMLMetadataProvider.xml";
         ifstream in(config.c_str());
         DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
@@ -63,13 +105,13 @@ public:
         auto_ptr_XMLCh file(s.c_str());
         doc->getDocumentElement()->setAttributeNS(nullptr,path.get(),file.get());
 
-        auto_ptr<MetadataProvider> metadataProvider(
-            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement())
+        scoped_ptr<MetadataProvider> metadataProvider(
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement(), false)
             );
         try {
             metadataProvider->init();
         }
-        catch (XMLToolingException& ex) {
+        catch (const XMLToolingException& ex) {
             TS_TRACE(ex.what());
             throw;
         }
@@ -83,7 +125,7 @@ public:
         TSM_ASSERT("Role lookup failed", find_if(descriptor->getIDPSSODescriptors(), isValidForProtocol(supportedProtocol2))!=nullptr);
 
         static const char* providerIdStr = "urn:mace:incommon:washington.edu";
-        auto_ptr<SAML2ArtifactType0004> artifact(
+        scoped_ptr<SAML2ArtifactType0004> artifact(
             new SAML2ArtifactType0004(
                 SecurityHelper::doHash("SHA1", providerIdStr, strlen(providerIdStr), false), 1
                 )
@@ -93,8 +135,10 @@ public:
         assertEquals("Entity's ID does not match requested ID", entityID, descriptor->getEntityID());
     }
 
+
     void testHTTPProvider()
     {
+        skipNetworked();
         string config = data_path + "saml2/metadata/HTTPMetadataProvider.xml";
         ifstream in(config.c_str());
         DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
@@ -106,12 +150,12 @@ public:
         auto_ptr_XMLCh file(s.c_str());
         doc->getDocumentElement()->setAttributeNS(nullptr, path.get(), file.get());
 #endif
-        auto_ptr<MetadataProvider> metadataProvider(\
-            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER, doc->getDocumentElement())
+        scoped_ptr<MetadataProvider> metadataProvider(\
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER, doc->getDocumentElement(), false)
             );
         try {
             metadataProvider->init();
-        } catch (XMLToolingException& ex) {
+        } catch (const XMLToolingException& ex) {
             TS_TRACE(ex.what());
             throw;
         }
@@ -125,7 +169,7 @@ public:
         TSM_ASSERT("Role lookup failed", find_if(descriptor->getIDPSSODescriptors(), isValidForProtocol(supportedProtocol2)) != nullptr);
 
         static const char* providerIdStr = "urn:mace:incommon:washington.edu";
-        auto_ptr<SAML2ArtifactType0004> artifact(
+        scoped_ptr<SAML2ArtifactType0004> artifact(
             new SAML2ArtifactType0004(
                 SecurityHelper::doHash("SHA1", providerIdStr, strlen(providerIdStr), false), 1
                 )
@@ -138,6 +182,7 @@ public:
 
 
     void testXMLWithBlacklists() {
+        skipNetworked();
         string config = data_path + "saml2/metadata/XMLWithBlacklists.xml";
         ifstream in(config.c_str());
         DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
@@ -148,13 +193,13 @@ public:
         auto_ptr_XMLCh file(s.c_str());
         doc->getDocumentElement()->setAttributeNS(nullptr,path.get(),file.get());
 
-        auto_ptr<MetadataProvider> metadataProvider(
-            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement())
+        scoped_ptr<MetadataProvider> metadataProvider(
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement(), false)
             );
         try {
             metadataProvider->init();
         }
-        catch (XMLToolingException& ex) {
+        catch (const XMLToolingException& ex) {
             TS_TRACE(ex.what());
             throw;
         }
@@ -168,6 +213,7 @@ public:
     }
 
     void testXMLWithWhitelists() {
+        skipNetworked();
         string config = data_path + "saml2/metadata/XMLWithWhitelists.xml";
         ifstream in(config.c_str());
         DOMDocument* doc=XMLToolingConfig::getConfig().getParser().parse(in);
@@ -178,13 +224,13 @@ public:
         auto_ptr_XMLCh file(s.c_str());
         doc->getDocumentElement()->setAttributeNS(nullptr,path.get(),file.get());
 
-        auto_ptr<MetadataProvider> metadataProvider(
-            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement())
+        scoped_ptr<MetadataProvider> metadataProvider(
+            SAMLConfig::getConfig().MetadataProviderManager.newPlugin(XML_METADATA_PROVIDER,doc->getDocumentElement(), false)
             );
         try {
             metadataProvider->init();
         }
-        catch (XMLToolingException& ex) {
+        catch (const XMLToolingException& ex) {
             TS_TRACE(ex.what());
             throw;
         }
